NAME

Future::IO::Resolver::Using::LibAsyncNS - implement Future::IO::Resolver using libasyncns

DESCRIPTION

This module provides a backend implementation for Future::IO::Resolver which uses libasyncns (via the Net::LibAsyncNS module) to perform its lookups.

This should not be used directly, but is instead made available via the main dispatch methods in Future::IO::Resolver itself.

AUTHOR

Paul Evans <leonerd@leonerd.org.uk>