NAME

Future::IO::Resolver::Using::Socket - implement Future::IO::Resolver by wrapping the functions provided by Socket

DESCRIPTION

This module provides a backend implementation for Future::IO::Resolver which uses the regular Socket functions to perform lookups. In order to operate asynchronously, these calls are made from a forked side-car process.

This should not be used directly, but is instead made available via the main dispatch methods in Future::IO::Resolver itself.

TODO

  • The pipe() + fork() mechanism used internally should be extracted into a shared helper module, as none of it is specific to name resolvers. It can then be expanded to permit possibly multiple workers, etc. This would be similar to the way that IO::Async::Resolver uses IO::Async::Function.

AUTHOR

Paul Evans <leonerd@leonerd.org.uk>